/**
 * maintain information for each peer
 *
 * (c) Columbia University, 2001-2004, All Rights Reserved.
 * Author: Weibin Zhao
 */

import java.util.*;

class Peer {
    String fqdn;                // fqdn of this peer 
    String url;                 // url of this peer (has IP address) 
    String scope;               // serving scope
    slpTcpHandler tcp;          // reference to peering connection
    boolean directFwd;          // directFwd is enabled or not
    boolean pflag;              // has done anti-entropy or not 
                                // for PUSH model, anti-entropy is performed
                                // with one peer at a time.
    int aliveTimer;             // alive timer

    Peer(String fqdn, String url, String scope, slpTcpHandler tcp) {
        this.fqdn  = fqdn;
        this.url   = url;
        this.scope = scope;
        this.tcp   = tcp;
        directFwd  = false;
        pflag      = false;
        aliveTimer = Const.expire_interval + Const.mainTimer_interval;
    }

    public synchronized int getAliveTimer() {
        aliveTimer -= Const.mainTimer_interval;
        return aliveTimer;
    }

    public synchronized void resetAliveTimer() {
        aliveTimer = Const.expire_interval;
    }

    public synchronized String getFQDN() {       // FQDN
        return fqdn;
    }

    public synchronized String getURL() {        // URL
        return url;
    }

    public synchronized String getScope() {      // scope
        return scope;
    }

    public synchronized slpTcpHandler getTcp() { // get peering connection
        return tcp;
    }

    public synchronized void setTcp(slpTcpHandler tcp) { // set peering conn
        this.tcp = tcp;
    }

    public synchronized void closeTcp() {        // close peering connection
        if (tcp != null) {
            tcp.close();
            tcp = null;
        }
    }

    public synchronized void setDirectFwd(boolean mode) { // direct forwarding
        directFwd = mode;
    }

    public synchronized boolean isDirectFwd() { // is direct forwarding
        return directFwd;
    }

    public synchronized boolean getPflag() { // anti-entropy flag
        return pflag;                        // for PUSH model only
    }

    public synchronized void setPflag() {
        pflag = true;
    }
}
